@@ -8,6 +8,11 @@
 #' @return The list of the paths
 #'
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
+#' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
+#'  "sen2r": An R toolbox for automatically downloading and preprocessing 
+#'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. DOI: 
+#'  \href{https://doi.org/10.1016/j.cageo.2020.104473}{10.1016/j.cageo.2020.104473}, 
+#'  URL: \url{http://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @importFrom jsonlite fromJSON
 #' @export
@@ -47,7 +52,7 @@ load_binpaths <- function(bins = NULL) {
   ## Check that the required binaries are present
   
   # Check GDAL
-  if ("gdal" %in% bins & is.null(binpaths$gdalinfo)) {
+  if ("gdal" %in% bins & is.null(binpaths$gdal_calc)) {
     check_gdal()
     binpaths <- jsonlite::fromJSON(binpaths_file)
   }
