@@ -66,6 +66,7 @@ safe_is_online <- function(s2_prodlist = NULL, apihub = NA, verbose = TRUE) {
   
   # check for availability
   s2_availability <- sapply(s2_prodlist, function(p) {
+    if (grepl("^http.+Products\\(.+\\)/\\$value$", p)) {
     tryCatch(
       as.logical(content(RETRY(
         verb = "GET",
@@ -80,6 +81,7 @@ safe_is_online <- function(s2_prodlist = NULL, apihub = NA, verbose = TRUE) {
         NA
       }
     )
+    } else if (grepl("^gs://gcp-public-data-sentinel-2", p)) {TRUE} else {NA}
   })
   
   names(s2_availability) <- names(s2_prodlist)
